-- GroupAccept 1.3, Code by Rakzul (EU-Magtheridon)
-- Please don't edit anything here, configuration is moved to /ga command

-- Default options
GroupAcceptDB = {
   friends = true,
   guild = true,
   vip = false,
   viplist = {},
}

local lower = string.lower

-- Checking someone's "friend" status
local function IsFriend(name)
   name = lower(name)

   -- Check VIP list
   if (GroupAcceptDB.vip) then
      for k, v in pairs(GroupAcceptDB.viplist) do
         if (v == name) then
            return true
         end
      end
   end

   -- Check friend list
   if (GroupAcceptDB.friends) then
      for i = 1, GetNumFriends() do
         if (lower(GetFriendInfo(i)) == name) then
            return true
         end
      end
   end

   -- Finally check guild list
   if (GroupAcceptDB.guild and IsInGuild()) then
      for i = 1, GetNumGuildMembers() do
          if (lower(GetGuildRosterInfo(i)) == name) then
             return true
          end
      end
   end
   
   return false
end

-- Print function
local print = function(msg)
   print("|cFF00bfffGroupAccept|r: " .. msg)
end

-- Help display function
local function ShowHelp()
	print("/ga guild - Toggle group accept from guild members (currently " ..
      (GroupAcceptDB.guild and "ON" or "OFF") .. ")")
   print("/ga friends - Toggle group accept from friends (currently " ..
      (GroupAcceptDB.friends and "ON" or "OFF") .. ")")
	print("/ga vip - Toggle group accept from vip list (currently " ..
      (GroupAcceptDB.vip and "ON" or "OFF") .. ")")
	print("/ga addvip <name> - Add someone to vip list")
	print("/ga delvip <name> - Remove someone from vip list")
	print("/ga listvip - Print vip list")
end

-- Slash command function
SLASH_GROUPACCEPT1 = "/ga"
SLASH_GROUPACCEPT2 = "/groupaccept"
SlashCmdList["GROUPACCEPT"] = function(cmd)
   if ((not cmd) or (cmd == "")) then
      ShowHelp()
      return
   end

   cmd = lower(cmd)
	
   local args = {}
   for arg in cmd:gmatch("%S+") do
      table.insert(args, arg)
   end

   if (args[1] == "friends") then

      -- Toggle accept from friends
      GroupAcceptDB.friends = not GroupAcceptDB.friends
      print("Accept from friends: " .. (GroupAcceptDB.friends and "ON" or "OFF"))

   elseif (args[1] == "guild") then

      -- Toggle accept from guild
      GroupAcceptDB.guild = not GroupAcceptDB.guild
      print("Accept from guild members: " .. (GroupAcceptDB.guild and "ON" or "OFF"))

   elseif (args[1] == "vip") then

      -- Toggle accept from vip list
      GroupAcceptDB.vip = not GroupAcceptDB.vip
      print("Accept from VIP list: " .. (GroupAcceptDB.vip and "ON" or "OFF"))

   elseif (args[1] == "listvip") then

      -- Show vip list
      if (GroupAcceptDB.viplist[1]) then
         print("Listing VIP list:")
         for _, v in pairs(GroupAcceptDB.viplist) do
            print("   " .. v)
         end
      else
         print("VIP list is empty!")
      end

   elseif (args[1] == "addvip") then

      -- Add to vip list
      if ((not args[2]) or (args[2] == "")) then
         ShowHelp()
         return
      end

		tinsert(GroupAcceptDB.viplist, args[2])
		print("Added " .. args[2] .. " to VIP list")

   elseif (args[1] == "delvip") then

      -- Remove from vip list
      if ((not args[2]) or (args[2] == "")) then
         ShowHelp()
         return
      end

      for k, v in pairs(GroupAcceptDB.viplist) do
         if (v == args[2]) then
            tremove(GroupAcceptDB.viplist, k)
            print("Removed " .. args[2] .. " from VIP list")
         end
      end
   else
      ShowHelp()
   end
end

local f = CreateFrame("Frame")
f:RegisterEvent("PARTY_INVITE_REQUEST")
f:SetScript("OnEvent", function(frame, event, name)
   if (IsFriend(name)) then
      AcceptGroup()

      for i=1, STATICPOPUP_NUMDIALOGS do
         local dlg = _G["StaticPopup"..i]
         if (dlg:IsVisible() and dlg.which == "PARTY_INVITE") then
            dlg.inviteAccepted = 1
            break
         end
      end

      StaticPopup_Hide("PARTY_INVITE");
	end
end)